This introduces LipoProteinLipase (lpl), a simple tool for creating fat binaries. It represents a direct replacement of the creaky hccgenco.sh script, which had various issues. The format it uses is that of a code object bundle, generated by the Clang Offload Bundler. The output is always suffixed with the ".adipose" extension. It is shared with HCC. The hipcc script and associated tests are modified to use lpl. Help can be obtained by invoking lpl --help. A more computer-sciency / corporate friendly name is likely to be beneficial, which is a reason for choosing easily searchable/replaceable names such as lpl or adipose.

Αυτή η υποβολή περιλαμβάνεται σε:
Alex Voicu
2017-12-08 04:22:57 +00:00
γονέας faef491778
υποβολή 4e0739c68a
17 αρχεία άλλαξαν με 3958 προσθήκες και 94 διαγραφές
@@ -27,13 +27,13 @@ THE SOFTWARE.
extern float myDeviceGlobal;
extern float myDeviceGlobalArray[16];;
extern "C" __global__ void hello_world(hipLaunchParm lp, const float *a, float *b)
extern "C" __global__ void hello_world(const float *a, float *b)
{
int tx = hipThreadIdx_x;
b[tx] = a[tx];
}
extern "C" __global__ void test_globals(hipLaunchParm lp, const float *a, float *b)
extern "C" __global__ void test_globals(const float *a, float *b)
{
int tx = hipThreadIdx_x;
b[tx] = a[tx] + myDeviceGlobal+ myDeviceGlobalArray[tx%ARRAY_SIZE] ;